|
Neko 1.99.9
A portable framework for high-order spectral element flow simulations
|


Go to the source code of this file.
Classes | |
| struct | ax_helm_mfma_dispatch< T, LX, NWF > |
| __global__ void __launch_bounds__ | ( | (LX *LX *EB) | , |
| 3 | |||
| ) |
Device kernel for axhelm with padding in shared memory to remove bank conflicts when LX is a power of 2

| __syncthreads | ( | ) |
| __global__ void ax_helm_kernel_1d | ( | T *__restrict__ | w, |
| const T *__restrict__ | u, | ||
| const T *__restrict__ | dx, | ||
| const T *__restrict__ | dy, | ||
| const T *__restrict__ | dz, | ||
| const T *__restrict__ | dxt, | ||
| const T *__restrict__ | dyt, | ||
| const T *__restrict__ | dzt, | ||
| const T *__restrict__ | h1, | ||
| const T *__restrict__ | g11, | ||
| const T *__restrict__ | g22, | ||
| const T *__restrict__ | g33, | ||
| const T *__restrict__ | g12, | ||
| const T *__restrict__ | g13, | ||
| const T *__restrict__ | g23 | ||
| ) |
Device kernels for Ax helm
Definition at line 46 of file ax_helm_kernel.h.

| __global__ void ax_helm_kernel_vector_part2 | ( | T *__restrict__ | au, |
| T *__restrict__ | av, | ||
| T *__restrict__ | aw, | ||
| const T *__restrict__ | u, | ||
| const T *__restrict__ | v, | ||
| const T *__restrict__ | w, | ||
| const T *__restrict__ | h2, | ||
| const T *__restrict__ | B, | ||
| const int | n | ||
| ) |
| for | ( | ) |
| if | ( | active | ) |
| if | ( | eb | = = 0 | ) |
Definition at line 206 of file ax_helm_kernel.h.
Definition at line 198 of file ax_helm_kernel.h.
| __global__ void T* __restrict__ av |
Definition at line 642 of file ax_helm_kernel.h.
| __global__ void T* __restrict__ T* __restrict__ aw |
Definition at line 643 of file ax_helm_kernel.h.
| __global__ void T* __restrict__ T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ dx |
Definition at line 156 of file ax_helm_kernel.h.
| __global__ void T* __restrict__ T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ dy |
Definition at line 157 of file ax_helm_kernel.h.
| __global__ void T* __restrict__ T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ dz |
Definition at line 158 of file ax_helm_kernel.h.
| const int e_blk = blockIdx.x * EB + eb |
Definition at line 197 of file ax_helm_kernel.h.
Definition at line 196 of file ax_helm_kernel.h.
Definition at line 160 of file ax_helm_kernel.h.
Definition at line 163 of file ax_helm_kernel.h.
Definition at line 164 of file ax_helm_kernel.h.
Definition at line 161 of file ax_helm_kernel.h.
Definition at line 165 of file ax_helm_kernel.h.
Definition at line 162 of file ax_helm_kernel.h.
Definition at line 159 of file ax_helm_kernel.h.
| const int i = threadIdx.x |
Definition at line 201 of file ax_helm_kernel.h.
Definition at line 200 of file ax_helm_kernel.h.
Definition at line 166 of file ax_helm_kernel.h.
Definition at line 187 of file ax_helm_kernel.h.
| T rut |
Definition at line 189 of file ax_helm_kernel.h.
Definition at line 696 of file ax_helm_kernel.h.
Definition at line 693 of file ax_helm_kernel.h.
| T rvt |
Definition at line 701 of file ax_helm_kernel.h.
Definition at line 697 of file ax_helm_kernel.h.
Definition at line 188 of file ax_helm_kernel.h.
| T rwt |
Definition at line 702 of file ax_helm_kernel.h.
Definition at line 698 of file ax_helm_kernel.h.
| __shared__ T shdy[LX *(LX+1)] |
Definition at line 170 of file ax_helm_kernel.h.
| __shared__ T shdz[LX *(LX+1)] |
Definition at line 171 of file ax_helm_kernel.h.
| __shared__ T shu[EB *LX *(LX+1)] |
Definition at line 174 of file ax_helm_kernel.h.
| __shared__ T shur[EB *LX *LX] |
Definition at line 175 of file ax_helm_kernel.h.
| __shared__ T shus[EB *LX *(LX+1)] |
Definition at line 176 of file ax_helm_kernel.h.
| __shared__ T shv[EB *LX *(LX+1)] |
Definition at line 669 of file ax_helm_kernel.h.
| __shared__ T shvr[EB *LX *LX] |
Definition at line 670 of file ax_helm_kernel.h.
| __shared__ T shvs[EB *LX *(LX+1)] |
Definition at line 671 of file ax_helm_kernel.h.
| __shared__ T shw[EB *LX *(LX+1)] |
Definition at line 673 of file ax_helm_kernel.h.
| __shared__ T shwr[EB *LX *LX] |
Definition at line 674 of file ax_helm_kernel.h.
| __shared__ T shws[EB *LX *(LX+1)] |
Definition at line 675 of file ax_helm_kernel.h.
Definition at line 155 of file ax_helm_kernel.h.
Definition at line 645 of file ax_helm_kernel.h.
| __global__ void T* __restrict__ T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ w |
Definition at line 646 of file ax_helm_kernel.h.